//#region THE GLOBALS: 3rd party modules & environment variables
///////////////////////////////////////////////////////////////////
// app, http = parts of Express library
// io = part pf Socket.IO library
// isRoot = checks if the process is started as root (sudo etc.) - always returns boolean!
// port = port for the application
// PORT HAS THREE OPTIONS:
// 1. set in environment as PORT (this can be doen either as a command line ex. 
//    PORT=1984 node index.js
//    or (recomended) via an .env file in root)
// 2. defaults to 80 if environment isn't set, but ONLY if ran as root (sudo node index.js)
// 3. defaults to 1984 if neither of the above
///////////////////////////////////////////////////////////////////
require('dotenv').config(); // read .env file if exists
const fs = require('fs');
const express = require('express');
const app = express();
const http = require('http').Server(app);
const io = require('socket.io')(http);
const isRoot = process.getuid && process.getuid() === 0;
const port = process.env.PORT || (isRoot? 80 : 1984);
//#endregion

//#region defaults
app.use('/public', express.static( __dirname + '/../../public')); // public folder
const templatedir = __dirname + '/../../templates';
app.set('views', templatedir); // templates folder
app.set('view engine','hbs'); // we use handlebars as a very simple templating engine
app.get('/:template', function(req, res){
 const filename=req.params.template;
 fs.access( templatedir + '/' + filename + '.hbs', fs.F_OK, (err) => { // check if template exists
    if (err) {
      res.status(404).render(templatedir + '/404.hbs'); // if file doesn't exists - return 404
      return;
    }
    // template exists
    res.render(filename + '.hbs');
  });
});
//#endregion

//#region exports
http.listen(port, "localhost", function(){
  console.log('Server active on port: ' + port);
});
module.exports = {
    app,
    io,
}
//endregion